@@ -24,11 +24,12 @@ SARM SDK - 安全资产与风险管理平台SDK
     >>> organizations = client.organizations.create_batch([...])
 """
 
-__version__ = "1.0.15"
+__version__ = "1.0.26"
 __author__ = "Murphysec Team"
 __email__ = "developer@murphysec.com"
 
 from .client import SARMClient
+from .plugin import BasePlugin
 from .exceptions import (
     SARMException,
     SARMAPIError,
@@ -42,6 +43,7 @@ from .exceptions import (
 # 导出主要类和异常
 __all__ = [
     "SARMClient",
+    "BasePlugin",
     "SARMException", 
     "SARMAPIError",
     "SARMValidationError",
