@@ -22,6 +22,50 @@ class OrganizationAPI:
     def __init__(self, client: 'SARMClient'):
         self.client = client
     
+    def _validate_organization_data(self, organization: Dict[str, Any], record_index: int = 1) -> None:
+        """
+        验证组织数据的格式和内容
+        
+        Args:
+            organization: 组织数据字典
+            record_index: 记录索引，用于错误提示
+            
+        Raises:
+            SARMValidationError: 当数据验证失败时抛出
+        """
+        import re
+        
+        # 验证必填字段
+        if 'organize_name' not in organization:
+            raise SARMValidationError(f"第{record_index}条记录缺少必填字段 organize_name")
+        
+        # 验证数据类型
+        if 'organize_unique_id' in organization and not isinstance(organization['organize_unique_id'], str):
+            raise SARMValidationError(f"第{record_index}条记录的 organize_unique_id 必须是字符串类型")
+        
+        if not isinstance(organization['organize_name'], str):
+            raise SARMValidationError(f"第{record_index}条记录的 organize_name 必须是字符串类型")
+        
+        if 'organize_punique_id' in organization and not isinstance(organization['organize_punique_id'], str):
+            raise SARMValidationError(f"第{record_index}条记录的 organize_punique_id 必须是字符串类型")
+        
+        if 'organize_leader_unique_id' in organization and not isinstance(organization['organize_leader_unique_id'], str):
+            raise SARMValidationError(f"第{record_index}条记录的 organize_leader_unique_id 必须是字符串类型")
+        
+        if 'desc' in organization and not isinstance(organization['desc'], str):
+            raise SARMValidationError(f"第{record_index}条记录的 desc 必须是字符串类型")
+        
+        if 'dep_id' in organization and not isinstance(organization['dep_id'], str):
+            raise SARMValidationError(f"第{record_index}条记录的 dep_id 必须是字符串类型")
+        
+        # 验证字段值
+        if organization['organize_name'].strip() == '':
+            raise SARMValidationError(f"第{record_index}条记录的 organize_name 不能为空字符串")
+        if organization['organize_unique_id'].strip() == '':
+            raise SARMValidationError(f"第{record_index}条记录的 organize_unique_id 不能为空字符串")
+        if organization['organize_punique_id'].strip() == '':
+            raise SARMValidationError(f"第{record_index}条记录的 organize_unique_id 不能为空字符串")
+
     def create_batch(
         self,
         organizations: List[OrganizeInsert],
@@ -49,10 +93,13 @@ class OrganizationAPI:
         
         # 验证数据
         org_data = []
-        for org in organizations:
+        for i, org in enumerate(organizations):
             if isinstance(org, OrganizeInsert):
-                org_data.append(org.dict())
+                org_dict = org.dict()
+                self._validate_organization_data(org_dict, i + 1)
+                org_data.append(org_dict)
             else:
+                self._validate_organization_data(org, i + 1)
                 org_data.append(org)
         
         # 发送请求
@@ -105,6 +152,9 @@ class OrganizationAPI:
         Returns:
             批量操作结果
         """
+        if not isinstance(organization, (OrganizeInsert, dict)):
+            raise SARMValidationError("组织数据必须是 OrganizeInsert 对象或字典类型")
+        
         return self.create_batch([organization], execute_release=execute_release)
     
     def update_batch(
@@ -127,10 +177,13 @@ class OrganizationAPI:
         
         # 验证数据
         org_data = []
-        for org in organizations:
+        for i, org in enumerate(organizations):
             if isinstance(org, OrganizeInsert):
-                org_data.append(org.dict())
+                org_dict = org.dict()
+                self._validate_organization_data(org_dict, i + 1)
+                org_data.append(org_dict)
             else:
+                self._validate_organization_data(org, i + 1)
                 org_data.append(org)
         
         # 发送请求
@@ -183,6 +236,9 @@ class OrganizationAPI:
         Returns:
             批量操作结果
         """
+        if not isinstance(organization, (OrganizeInsert, dict)):
+            raise SARMValidationError("组织数据必须是 OrganizeInsert 对象或字典类型")
+        
         return self.update_batch([organization], execute_release=execute_release)
     
     def delete_batch(self, unique_ids: List[str]) -> Dict[str, Any]:
@@ -201,6 +257,16 @@ class OrganizationAPI:
         if not unique_ids:
             raise SARMValidationError("组织ID列表不能为空")
         
+        if not isinstance(unique_ids, list):
+            raise SARMValidationError("组织ID列表必须是列表类型")
+        
+        # 验证每个ID都是字符串类型
+        for i, unique_id in enumerate(unique_ids):
+            if not isinstance(unique_id, str):
+                raise SARMValidationError(f"第{i+1}个组织ID必须是字符串类型")
+            if unique_id.strip() == '':
+                raise SARMValidationError(f"第{i+1}个组织ID不能为空字符串")
+        
         response = self.client.post(
             '/api/organize/openapi/delete',
             data=unique_ids
@@ -218,6 +284,12 @@ class OrganizationAPI:
         Returns:
             删除结果
         """
+        if not isinstance(unique_id, str):
+            raise SARMValidationError("组织ID必须是字符串类型")
+        
+        if unique_id.strip() == '':
+            raise SARMValidationError("组织ID不能为空字符串")
+        
         return self.delete_batch([unique_id])
     
     def get(
@@ -239,6 +311,19 @@ class OrganizationAPI:
         Returns:
             组织列表和分页信息
         """
+        # 验证参数
+        if not isinstance(page, int) or page < 1:
+            raise SARMValidationError("页码必须是大于0的整数")
+        
+        if not isinstance(limit, int) or limit < 1 or limit > 1000:
+            raise SARMValidationError("每页条数必须是1-1000之间的整数")
+        
+        if organize_unique_id is not None and not isinstance(organize_unique_id, str):
+            raise SARMValidationError("组织唯一ID必须是字符串类型")
+        
+        if organize_name is not None and not isinstance(organize_name, str):
+            raise SARMValidationError("组织名称必须是字符串类型")
+        
         query_data = {
             "page": page,
             "limit": limit
@@ -380,11 +465,22 @@ class OrganizationAPI:
         if not users:
             raise SARMValidationError("用户列表不能为空")
         
+        if not isinstance(organize_unique_id, str):
+            raise SARMValidationError("组织唯一ID必须是字符串类型")
+        
+        if organize_unique_id.strip() == '':
+            raise SARMValidationError("组织唯一ID不能为空字符串")
+        
+        if not isinstance(users, list):
+            raise SARMValidationError("用户列表必须是列表类型")
+        
         user_data = []
-        for user in users:
+        for i, user in enumerate(users):
             if isinstance(user, OrganizeUser):
                 user_data.append(user.dict())
             else:
+                if not isinstance(user, dict):
+                    raise SARMValidationError(f"第{i+1}个用户数据必须是字典类型")
                 user_data.append(user)
         
         request_data = {
@@ -408,11 +504,16 @@ class OrganizationAPI:
         if not users:
             raise SARMValidationError("用户列表不能为空")
         
+        if not isinstance(users, list):
+            raise SARMValidationError("用户列表必须是列表类型")
+        
         user_data = []
-        for user in users:
+        for i, user in enumerate(users):
             if isinstance(user, OrganizeUser):
                 user_data.append(user.dict())
             else:
+                if not isinstance(user, dict):
+                    raise SARMValidationError(f"第{i+1}个用户数据必须是字典类型")
                 user_data.append(user)
         
         response = self.client.post('/api/organize_user/update', data=user_data)
@@ -444,6 +545,19 @@ class OrganizationAPI:
         Returns:
             操作结果
         """
+        if not organize_id:
+            raise SARMValidationError("组织ID列表不能为空")
+        
+        if not isinstance(organize_id, list):
+            raise SARMValidationError("组织ID列表必须是列表类型")
+        
+        # 验证每个ID都是字符串类型
+        for i, org_id in enumerate(organize_id):
+            if not isinstance(org_id, str):
+                raise SARMValidationError(f"第{i+1}个组织ID必须是字符串类型")
+            if org_id.strip() == '':
+                raise SARMValidationError(f"第{i+1}个组织ID不能为空字符串")
+        
         response = self.client.post('/api/organize/openapi/delete_pid', data=organize_id)
         return response
 
@@ -457,6 +571,19 @@ class OrganizationAPI:
         Returns:
             操作结果
         """
+        if not organize_id:
+            raise SARMValidationError("组织ID列表不能为空")
+        
+        if not isinstance(organize_id, list):
+            raise SARMValidationError("组织ID列表必须是列表类型")
+        
+        # 验证每个ID都是字符串类型
+        for i, org_id in enumerate(organize_id):
+            if not isinstance(org_id, str):
+                raise SARMValidationError(f"第{i+1}个组织ID必须是字符串类型")
+            if org_id.strip() == '':
+                raise SARMValidationError(f"第{i+1}个组织ID不能为空字符串")
+        
         response = self.client.post('/api/organize/openapi/delete_leader', data=organize_id)
         return response
     
@@ -483,6 +610,28 @@ class OrganizationAPI:
         Returns:
             用户列表和分页信息
         """
+        # 验证参数
+        if not isinstance(organize_unique_id, str):
+            raise SARMValidationError("组织唯一ID必须是字符串类型")
+        
+        if organize_unique_id.strip() == '':
+            raise SARMValidationError("组织唯一ID不能为空字符串")
+        
+        if not isinstance(page, int) or page < 1:
+            raise SARMValidationError("页码必须是大于0的整数")
+        
+        if not isinstance(limit, int) or limit < 1 or limit > 1000:
+            raise SARMValidationError("每页条数必须是1-1000之间的整数")
+        
+        if user_unique_id is not None and not isinstance(user_unique_id, str):
+            raise SARMValidationError("用户唯一ID必须是字符串类型")
+        
+        if user_name is not None and not isinstance(user_name, str):
+            raise SARMValidationError("用户名称必须是字符串类型")
+        
+        if enterprise_email is not None and not isinstance(enterprise_email, str):
+            raise SARMValidationError("企业邮箱必须是字符串类型")
+        
         user_info = {}
         if user_unique_id:
             user_info["organize_user_unique_id"] = user_unique_id
@@ -499,4 +648,4 @@ class OrganizationAPI:
         }
         
         response = self.client.post('/api/organize_user/list', data=query_data)
-        return response 
\ No newline at end of file
+        return response
\ No newline at end of file
